/**
 * CInputExpressCode - 表单项，手机验证码输入框
 * @author Tevin
 */

<template>
    <view class="c-input-express-code">
        <AtInput
            :name="itemRes.name"
            :title="itemRes.label"
            type="text"
            :placeholder="placeholder"
            :required="itemRes.required"
            :error="itemRes.error"
            :value="itemRes.formData[itemRes.name]"
            :onChange="evt=>itemRes.onChange(evt)"
        >
            <view
                class="c-input-express-btn"
                @tap="evt => handleScan()"
            ></view>
            <view class="c-input-express-scan">
                <view
                    v-show="!scaning"
                    class="gg-scan"
                ></view>
                <AtIcon
                    v-show="scaning"
                    value="loading"
                />
            </view>
        </AtInput>
    </view>
</template>

<script>
import Taro from '@tarojs/taro';
import { AtInput, AtIcon } from 'taro-ui-vue';
import { Tools } from '@components/common/Tools';
import './cInputExpressCode.scss';

export default {
    name: 'CInputExpressCode',
    components: {
        AtInput,
        AtIcon,
    },
    props: {
        // 表单数据资源（表单组件内部机制专用）
        itemRes: Object,
        // 占位提示
        placeholder: String,
    },
    data() {
        return {
            scaning: false,
        };
    },
    methods: {
        handleScan() {
            this.scaning = true;
            Taro.scanCode({
                onlyFromCamera: true,
                scanType: 'barCode',
                success: res => {
                    this.scaning = false;
                    if (!res.result || !/^[0-9a-zA-Z]*$/g.test(res.result)) {
                        Tools.toast('请扫描快递单号！');
                        return;
                    }
                    this.itemRes.onChange(res.result);
                },
                fail: err => {
                    Tools.toast('扫码失败！');
                    this.scaning = false;
                },
            });
        },
    },
};
</script>